@@ -9,7 +9,7 @@ use base 'Exporter';
 our @EXPORT_OK = qw/encode decode/;
 
 use version;
-our $VERSION = 'v1.4.0';
+our $VERSION = 'v1.6.0';
 
 use Carp;
 use Config;
@@ -17,6 +17,7 @@ use Scalar::Util qw/blessed/;
 
 use Moo 2.002004; # safer generated code
 use boolean;
+use BSON::OID;
 
 use constant {
     HAS_INT64 => $Config{use64bitint},
@@ -385,6 +386,19 @@ sub clone {
 # public class methods
 #--------------------------------------------------------------------------#
 
+#pod =method create_oid
+#pod
+#pod     $oid = BSON->create_oid;
+#pod
+#pod This class method returns a new L<BSON::OID>.  This abstracts OID
+#pod generation away from any specific Object ID class and makes it an interface
+#pod on a BSON codec.  Alternative BSON codecs should define a similar class
+#pod method that returns an Object ID of whatever type is appropriate.
+#pod
+#pod =cut
+
+sub create_oid { return BSON::OID->new }
+
 #pod =method inflate_extjson
 #pod
 #pod     use JSON::MaybeXS;
@@ -641,7 +655,7 @@ BSON - BSON serialization and deserialization
 
 =head1 VERSION
 
-version v1.4.0
+version v1.6.0
 
 =head1 SYNOPSIS
 
@@ -916,6 +930,15 @@ wrap_strings - overrides codec default
 Constructs a copy of the original codec, but allows changing
 attributes in the copy.
 
+=head2 create_oid
+
+    $oid = BSON->create_oid;
+
+This class method returns a new L<BSON::OID>.  This abstracts OID
+generation away from any specific Object ID class and makes it an interface
+on a BSON codec.  Alternative BSON codecs should define a similar class
+method that returns an Object ID of whatever type is appropriate.
+
 =head2 inflate_extjson
 
     use JSON::MaybeXS;
@@ -1181,7 +1204,7 @@ Oleg Kostyuk <cub@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2017 by Stefan G. and MongoDB, Inc.
+This software is Copyright (c) 2018 by Stefan G. and MongoDB, Inc.
 
 This is free software, licensed under:
 
