@@ -1,4 +1,4 @@
-use 5.008001;
+use 5.010001;
 use strict;
 use warnings;
 
@@ -6,7 +6,7 @@ package BSON::Binary;
 # ABSTRACT: Legacy BSON type wrapper for binary data (DEPRECATED)
 
 use version;
-our $VERSION = 'v1.2.2';
+our $VERSION = 'v1.6.0';
 
 our $TYPE_SIMPLE       = 0x00;
 our $TYPE_BYTES        = 0x02;
@@ -43,7 +43,7 @@ sub subtype {
 sub to_s {
     my $self = shift;
     my @data = @{ $self->data };
-    return pack( 'lC*', scalar(@data), $self->type, @data );
+    return pack( 'l<C*', scalar(@data), $self->type, @data );
 }
 
 use overload '""' => \&to_s;
@@ -60,7 +60,7 @@ BSON::Binary - Legacy BSON type wrapper for binary data (DEPRECATED)
 
 =head1 VERSION
 
-version v1.2.2
+version v1.6.0
 
 =head1 DESCRIPTION
 
@@ -89,7 +89,7 @@ Stefan G. <minimalist@lavabit.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2016 by Stefan G. and MongoDB, Inc.
+This software is Copyright (c) 2018 by Stefan G. and MongoDB, Inc.
 
 This is free software, licensed under:
 
