@@ -1,4 +1,4 @@
-use 5.008001;
+use 5.010001;
 use strict;
 use warnings;
 
@@ -6,7 +6,7 @@ package BSON::Int64;
 # ABSTRACT: BSON type wrapper for Int64
 
 use version;
-our $VERSION = 'v1.2.2';
+our $VERSION = 'v1.6.0';
 
 use Carp;
 use Config;
@@ -56,7 +56,7 @@ BEGIN {
         }
     }
     else {
-        my $packed_min_int64 = pack("q", $min_int64);
+        my $packed_min_int64 = pack("q<", $min_int64);
         *BUILD = sub {
             my $self = shift;
 
@@ -65,7 +65,7 @@ BEGIN {
             if ( $value >= 0 && $value > $max_int64 ) {
                 $value = $max_int64;
             }
-            elsif ( $value < 0 && pack("q", $value) eq $packed_min_int64 ) {
+            elsif ( $value < 0 && pack("q<", $value) eq $packed_min_int64 ) {
                 $value = $min_int64;
             }
 
@@ -131,7 +131,7 @@ BSON::Int64 - BSON type wrapper for Int64
 
 =head1 VERSION
 
-version v1.2.2
+version v1.6.0
 
 =head1 SYNOPSIS
 
@@ -194,7 +194,7 @@ Stefan G. <minimalist@lavabit.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2016 by Stefan G. and MongoDB, Inc.
+This software is Copyright (c) 2018 by Stefan G. and MongoDB, Inc.
 
 This is free software, licensed under:
 
