@@ -1,4 +1,4 @@
-use 5.008001;
+use 5.010001;
 use strict;
 use warnings;
 
@@ -6,7 +6,7 @@ package BSON::PP;
 # ABSTRACT: Pure Perl BSON implementation
 
 use version;
-our $VERSION = 'v1.2.2';
+our $VERSION = 'v1.6.0';
 
 use B;
 use Carp;
@@ -43,17 +43,17 @@ my $bools_re = qr/::(?:Boolean|_Bool|Bool)\z/;
 use constant {
 
     BSON_TYPE_NAME => "CZ*",
-    BSON_DOUBLE => "d",
+    BSON_DOUBLE => "d<",
     BSON_STRING => "V/Z*",
     BSON_BOOLEAN => "C",
     BSON_REGEX => "Z*Z*",
     BSON_JSCODE => "",
-    BSON_INT32 => "l",
-    BSON_INT64 => "q",
+    BSON_INT32 => "l<",
+    BSON_INT64 => "q<",
     BSON_8BYTES => "a8",
     BSON_16BYTES => "a16",
-    BSON_TIMESTAMP => "LL",
-    BSON_CODE_W_SCOPE => "l",
+    BSON_TIMESTAMP => "L<L<",
+    BSON_CODE_W_SCOPE => "l<",
     BSON_REMAINING => 'a*',
     BSON_SKIP_4_BYTES => 'x4',
     BSON_OBJECTID => 'a12',
@@ -806,7 +806,7 @@ BSON::PP - Pure Perl BSON implementation
 
 =head1 VERSION
 
-version v1.2.2
+version v1.6.0
 
 =head1 DESCRIPTION
 
@@ -830,7 +830,7 @@ Stefan G. <minimalist@lavabit.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2016 by Stefan G. and MongoDB, Inc.
+This software is Copyright (c) 2018 by Stefan G. and MongoDB, Inc.
 
 This is free software, licensed under:
 
